all.Valsm<-function(){
     cat("\n")
     note_for_Valsm_input()
     cat("\n")
     note_for_close_window()
     ValSMMpar<-data.frame(parameter=c("age (yr)","INDI","CBZ","ka","D (mg)","tau (hr)"),value=c(0))
     ValSMMpar<-edit(ValSMMpar)
##     ValSMMpar<-ycheck(ValSMMpar)
     cat("\n")
     note_for_Valsm_conc_input()
     cat("\n")
     note_for_close_window()
     ValSMpar<-data.frame(ts=c(0),conc=c(0))
     ValSMpar<-edit(ValSMpar)
     ValSMpar<-mscheck(ValSMpar)
     cat("\n")
     Val.sm(length(ValSMpar$ts),ValSMpar$conc,ValSMpar$ts,ValSMMpar[6,2],ValSMMpar[5,2],ValSMMpar[1,2],ValSMMpar[3,2],ValSMMpar[2,2],ValSMMpar[4,2])
     note_for_convergence_plots()
     convergence_plots_sep()
     note_for_Valsm_output()
     show(samplesStats("*"))
     cat("\n") 
     C<-Valcpr(ValSMMpar[4,2],ValSMMpar[5,2],ValSMMpar[6,2],ValSMMpar[6,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     show(coutput)    
     cat("\n") 
     Val.more(ValSMMpar[4,2])
}